==> virtuoso-opensource-4.5.7.tar.gz: virtuoso-opensource-4.5.7/libsrc/Wi/odbcinc.h <==
/*
 *  odbcinc.h
 *
 *  $Id: odbcinc.h,v 1.2 2006/04/20 18:01:53 source Exp $
 *
 *  Include the ODBC header, whichever appropriate
 *  
 *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 *  project.
 *  
 *  Copyright (C) 1998-2006 OpenLink Software
 *  
 *  This project is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; only version 2 of the License, dated June 1991.
 *  
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *  
 *  
*/

#ifndef __V_ODBCINC_H
#define __V_ODBCINC_H

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#if (defined (WIN32) || defined (UNIX_ODBC) || defined(__BORLANDC__)) && !defined (UDBC)
# include "Dk.h"
# ifdef WIN32
#  include <windows.h>
# endif
# include <sql.h>
# include <sqlext.h>
# include <sqlucode.h>
# if defined (WIN32)
#  include <odbcinst.h>
#  define ERR_STRING	"[OpenLink][Virtuoso ODBC Driver]"
# else
#  define ERR_STRING	"[OpenLink][Virtuoso iODBC Driver]"
# endif

# ifndef SQL_COPT_SS_BASE
#  define SQL_COPT_SS_BASE		1200
#  define SQL_COPT_SS_ENLIST_IN_DTC	(SQL_COPT_SS_BASE+7)
#  define SQL_COPT_SS_ENLIST_IN_XA	(SQL_COPT_SS_BASE+8)
# endif

# if defined (WIN32)
#  ifndef HAVE_ODBCINST_H
#   define HAVE_ODBCINST_H
#  endif
# else
#  ifdef NO_UDBC_SDK
#   include <iodbcinst.h>
#   define HAVE_ODBCINST_H
#  else
#   include "iodbcinst.h"
#  endif
# endif

#else /* unix */
# define ERR_STRING	"[Virtuoso Driver]"
# include <sql.h>
# include <sqlext.h>
# include <iodbcext.h>
# ifndef NO_UDBC_SDK
typedef SQLCHAR SQLTCHAR;
#  if !defined (__ODBC3_DEFINES) && (ODBCVER < 0x0300)
#   define __ODBC3_DEFINES 1
typedef void * SQLHANDLE;
#   define SQL_TYPE_DATE 91
#   define SQL_TYPE_TIME 92
#   define SQL_TYPE_TIMESTAMP 93
#   define SQL_PARAM_SUCCESS	0
#   define SQL_PARAM_ERROR		5
#   define SQL_PARAM_SUCCESS_WITH_INFO	6
#   define SQL_PARAM_UNUSED	7

#  endif /* __ODBC3_DEFINES */
# endif /* NO_UDBC_SDK */
#endif /* UNIX */

/* these are from sqlucode.h */
#ifndef SQL_WCHAR
#  define SQL_WCHAR		(-8)
#  define SQL_C_WCHAR		SQL_WCHAR
#endif

#ifndef SQL_WVARCHAR
#  define SQL_WVARCHAR		(-9)
#  define SQL_C_WVARCHAR 	SQL_WVARCHAR
#endif

#ifndef SQL_WLONGVARCHAR
#  define SQL_WLONGVARCHAR	(-10)
#  define SQL_C_WLONGVARCHAR	SQL_WLONGVARCHAR
#endif

#ifndef SQL_FN_CVT_CAST
#  define SQL_FN_CVT_CAST	0x00000002L
#endif

/* from iodbcext.h */
#ifndef SQL_GETLASTSERIAL
#define SQL_GETLASTSERIAL 1049L  
#endif


#ifndef WIN32
#ifndef SQLLEN
#define SQLLEN SDWORD
#endif
#ifndef SQLULEN
#define SQLULEN UDWORD
#endif
#ifndef SQLSETPOSIROW
#define SQLSETPOSIROW SQLUSMALLINT
#endif
#endif

#define IS_INTERSOLV(drvr_name) (drvr_name[0] == 'I' && drvr_name[1] == 'V')
#define IS_ORACLE(rcon) (strindex (rcon->rc_dbms, "Oracle"))
#define IS_SQLSERVER(rcon) (strstr (rcon->rc_dbms, "SQL Server") || strstr (rcon->rc_dbms, "S Q L   S e r v e r"))
#define IS_SQLSERVER_RDS(rds) (strstr (rds_get_info (rds, SQL_DBMS_NAME), "SQL Server") || strstr (rds_get_info (rds, SQL_DBMS_NAME), "S Q L   S e r v e r"))
#define IS_SYBASE_RDS(rds) \
		( \
		  (strstr (rds_get_info (rds, SQL_DBMS_NAME), "SQL Server") || \
		   strstr (rds_get_info (rds, SQL_DBMS_NAME), "Sybase 11 (ctlib)") || \
		   strstr (rds_get_info (rds, SQL_DBMS_NAME), "S Q L   S e r v e r") \
		  ) && \
		  !(strstr (rds_get_info (rds, SQL_DBMS_NAME), "Microsoft") || \
		   strstr (rds_get_info (rds, SQL_DBMS_NAME), "M i c r o s o f t") \
		  ) \
		)
#define IS_VIRTUOSO_RDS(rds) (strstr (rds_get_info (rds, SQL_DBMS_NAME), "Virtuoso") != NULL)
#define IS_VIASERV_RDS(rds) ( \
		  (strstr (rds_get_info (rds, SQL_DBMS_NAME), "ViaSQL")) || \
 		  (!strcmp (rds_get_info (rds, SQL_DBMS_NAME), "LDS")) || \
		  (strstr (rds_get_info (rds, SQL_DRIVER_VER), "ViaSQL")) \
		)
#define IS_ORACLE_RDS(rds) (strindex (rds_get_info (rds, SQL_DBMS_NAME), "Oracle"))
#define SHOULD_USE_SCROLLABLE(rcon) (IS_SQLSERVER (rcon))
#define SHOULD_USE_SCROLLABLE_RDS(rds) (IS_SQLSERVER_RDS (rds))

#define IS_ORACLE_NATIVE_RDS(rds) (IS_ORACLE_RDS(rds) && \
    ((0 == strncmp(rds_get_info (rds, SQL_DRIVER_NAME),"SQORA", 5)) || \
     (0 == strncmp(rds_get_info (rds, SQL_DRIVER_NAME),"SQOCI", 5))))

#define IS_ORACLE_NATIVE_DRIVER(rcon) (IS_ORACLE(rcon) && \
    ((0 == strncmp(rcon->rc_driver_name, "SQORA", 5)) || \
     (0 == strncmp(rcon->rc_driver_name, "SQOCI", 5))))
#endif

==> virtuoso-opensource-5.0.1.tar.gz: virtuoso-opensource-5.0.1/libsrc/Wi/odbcinc.h <==
/*
 *  odbcinc.h
 *
 *  $Id: odbcinc.h,v 1.3 2007/03/16 12:51:19 source Exp $
 *
 *  Include the ODBC header, whichever appropriate
 *  
 *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 *  project.
 *  
 *  Copyright (C) 1998-2006 OpenLink Software
 *  
 *  This project is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; only version 2 of the License, dated June 1991.
 *  
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *  
 *  
*/

#ifndef __V_ODBCINC_H
#define __V_ODBCINC_H

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#if (defined (WIN32) || defined (UNIX_ODBC)) && !defined (UDBC)
# include "Dk.h"
# ifdef WIN32
#  include <windows.h>
# endif
# include <sql.h>
# include <sqlext.h>
# include <sqlucode.h>
# if defined (WIN32)
#  include <odbcinst.h>
#  define ERR_STRING	"[OpenLink][Virtuoso ODBC Driver]"
# else
#  define ERR_STRING	"[OpenLink][Virtuoso iODBC Driver]"
# endif

# ifndef SQL_COPT_SS_BASE
#  define SQL_COPT_SS_BASE		1200
#  define SQL_COPT_SS_ENLIST_IN_DTC	(SQL_COPT_SS_BASE+7)
#  define SQL_COPT_SS_ENLIST_IN_XA	(SQL_COPT_SS_BASE+8)
# endif

# if defined (WIN32)
#  ifndef HAVE_ODBCINST_H
#   define HAVE_ODBCINST_H
#  endif
# else
#  ifdef NO_UDBC_SDK
#   include <iodbcinst.h>
#   define HAVE_ODBCINST_H
#  else
#   include "iodbcinst.h"
#  endif
# endif

#else /* unix */
# define ERR_STRING	"[Virtuoso Driver]"
# include <sql.h>
# include <sqlext.h>
# include <iodbcext.h>
# ifndef NO_UDBC_SDK
typedef SQLCHAR SQLTCHAR;
#  if !defined (__ODBC3_DEFINES) && (ODBCVER < 0x0300)
#   define __ODBC3_DEFINES 1
typedef void * SQLHANDLE;
#   define SQL_TYPE_DATE 91
#   define SQL_TYPE_TIME 92
#   define SQL_TYPE_TIMESTAMP 93
#   define SQL_PARAM_SUCCESS	0
#   define SQL_PARAM_ERROR		5
#   define SQL_PARAM_SUCCESS_WITH_INFO	6
#   define SQL_PARAM_UNUSED	7

#  endif /* __ODBC3_DEFINES */
# endif /* NO_UDBC_SDK */
#endif /* UNIX */

/* these are from sqlucode.h */
#ifndef SQL_WCHAR
#  define SQL_WCHAR		(-8)
#  define SQL_C_WCHAR		SQL_WCHAR
#endif

#ifndef SQL_WVARCHAR
#  define SQL_WVARCHAR		(-9)
#  define SQL_C_WVARCHAR 	SQL_WVARCHAR
#endif

#ifndef SQL_WLONGVARCHAR
#  define SQL_WLONGVARCHAR	(-10)
#  define SQL_C_WLONGVARCHAR	SQL_WLONGVARCHAR
#endif

#ifndef SQL_FN_CVT_CAST
#  define SQL_FN_CVT_CAST	0x00000002L
#endif

/* from iodbcext.h */
#ifndef SQL_GETLASTSERIAL
#define SQL_GETLASTSERIAL 1049L  
#endif


#ifndef WIN32
#ifndef SQLLEN
#define SQLLEN SDWORD
#endif
#ifndef SQLULEN
#define SQLULEN UDWORD
#endif
#ifndef SQLSETPOSIROW
#define SQLSETPOSIROW SQLUSMALLINT
#endif
#endif

#define IS_INTERSOLV(drvr_name) (drvr_name[0] == 'I' && drvr_name[1] == 'V')
#define IS_ORACLE(rcon) (strindex (rcon->rc_dbms, "Oracle"))
#define IS_SQLSERVER(rcon) (strstr (rcon->rc_dbms, "SQL Server") || strstr (rcon->rc_dbms, "S Q L   S e r v e r"))
#define IS_SQLSERVER_RDS(rds) (strstr (rds_get_info (rds, SQL_DBMS_NAME), "SQL Server") || strstr (rds_get_info (rds, SQL_DBMS_NAME), "S Q L   S e r v e r"))
#define IS_SYBASE_RDS(rds) \
		( \
		  (strstr (rds_get_info (rds, SQL_DBMS_NAME), "SQL Server") || \
		   strstr (rds_get_info (rds, SQL_DBMS_NAME), "Sybase 11 (ctlib)") || \
		   strstr (rds_get_info (rds, SQL_DBMS_NAME), "S Q L   S e r v e r") \
		  ) && \
		  !(strstr (rds_get_info (rds, SQL_DBMS_NAME), "Microsoft") || \
		   strstr (rds_get_info (rds, SQL_DBMS_NAME), "M i c r o s o f t") \
		  ) \
		)
#define IS_VIRTUOSO_RDS(rds) (strstr (rds_get_info (rds, SQL_DBMS_NAME), "Virtuoso") != NULL)
#define IS_VIASERV_RDS(rds) ( \
		  (strstr (rds_get_info (rds, SQL_DBMS_NAME), "ViaSQL")) || \
 		  (!strcmp (rds_get_info (rds, SQL_DBMS_NAME), "LDS")) || \
		  (strstr (rds_get_info (rds, SQL_DRIVER_VER), "ViaSQL")) \
		)
#define IS_ORACLE_RDS(rds) (strindex (rds_get_info (rds, SQL_DBMS_NAME), "Oracle"))
#define SHOULD_USE_SCROLLABLE(rcon) (IS_SQLSERVER (rcon))
#define SHOULD_USE_SCROLLABLE_RDS(rds) (IS_SQLSERVER_RDS (rds))

#define IS_ORACLE_NATIVE_RDS(rds) (IS_ORACLE_RDS(rds) && \
    ((0 == strncmp(rds_get_info (rds, SQL_DRIVER_NAME),"SQORA", 5)) || \
     (0 == strncmp(rds_get_info (rds, SQL_DRIVER_NAME),"SQOCI", 5))))

#define IS_ORACLE_NATIVE_DRIVER(rcon) (IS_ORACLE(rcon) && \
    ((0 == strncmp(rcon->rc_driver_name, "SQORA", 5)) || \
     (0 == strncmp(rcon->rc_driver_name, "SQOCI", 5))))
#endif
